import { asHTTPGraphQLRequest } from './asHTTPGraphQLRequest.js';
export function startServerAndCreateCloudflareWorkersHandler(server, options) {
    server.startInBackgroundHandlingStartupErrorsByLoggingAndFailingAllRequests();
    const defaultContext = () => Promise.resolve({});
    const contextFunction = options?.context ?? defaultContext;
    return async function apolloServerIntegrationCloudflareWorkersHandler(request, env, ctx) {
        // const { method, url } = request
        // const { pathname } = new URL(url)
        // if (pathname !== options?.path || method !== 'POST') {
        //   return new Response('Path not found.', {
        //     status: 404,
        //   })
        // }
        let httpGraphqlResponse;
        try {
            httpGraphqlResponse = await server.executeHTTPGraphQLRequest({
                httpGraphQLRequest: await asHTTPGraphQLRequest(request),
                context() {
                    return contextFunction({
                        ctx,
                        env,
                        request,
                    });
                },
            });
        }
        catch (err) {
            const error = err instanceof Error ? err : new Error(String(err)); // TODO: do it better? 🤷‍♂️
            return new Response(error.message, {
                status: 500,
            });
        }
        const { body, headers, status } = httpGraphqlResponse;
        if (body.kind === 'chunked') {
            // TODO: check if this is possible in Cloudflare Workers, then implement it
            throw new Error('Incremental delivery not implemented.');
        }
        headers.set('content-length', String(new TextEncoder().encode(body.string).byteLength));
        return new Response(body.string, {
            headers,
            status: status ?? 200, // TODO: is returning 200 as fallback correct? are the types wrong?
        });
    };
}
//# sourceMappingURL=startServerAndCreateCloudflareWorkersHandler.js.map